#! /bin/bash 

#    Paolo Lulli 2018 https://kevwe.se 
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.

cd $(dirname $0)
HOMEDIR=$(pwd)
DATE=$(date '+%Y%m%d')

#..............................
source ./mail-setup.cfg
#..............................

function initPackager(){
	apt-get update
	apt-get upgrade
}

function mailserver_install(){
	mailserver_name=$1
	mailserver_domain=$2

	apt-get install \
		m4 postfix procmail fetchmail mailutils \
	  	amavisd-new clamav build-essential clamav-daemon clamav spamassassin \
	  	mailutils  dovecot-core dovecot-imapd \
		opendkim opendkim-tools

	openssl req -new -x509 -nodes -out /etc/ssl/certs/ssl-mail.pem -keyout /etc/ssl/private/ssl-mail.key -days 3650
	newaliases
	SCRIPT=$(mktemp /tmp/XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX)
	m4 -D__MAIN_HOSTNAME__=$mailserver_name $HOMEDIR/template/postfix/main.cf.m4 > $SCRIPT
	cp /etc/postfix/main.cf  /etc/postfix/main.cf.$DATE
	cp $SCRIPT /etc/postfix/main.cf
	touch /etc/postfix/virtual
	postmap /etc/postfix/main.cf
	postmap /etc/postfix/virtual
	/etc/init.d/postfix restart
	cp /etc/procmailrc /etc/procmailrc.$DATE
	cp $HOMEDIR/template/procmailrc /etc/procmailrc
	cp /etc/dovecot/dovecot.conf /etc/dovecot/dovecot.conf.$DATE
	cp $HOMEDIR/template/dovecot/dovecot.conf /etc/dovecot/dovecot.conf
	cp /etc/pam.d/imap /etc/pam.d/imap.$DATE
	cp $HOMEDIR/template/pam.d/imap /etc/pam.d/imap
	mkdir -p /etc/opendkim
	mkdir -p /etc/opendkim/$mailserver_name
	m4 -D__MAIN_DOMAIN__=$mailserver_domain $HOMEDIR/template/opendkim/signing_table.m4 >  /etc/opendkim/signing.table
	m4 -D__MAIN_DOMAIN__=$mailserver_domain $HOMEDIR/template/opendkim/key_table.m4 >  	 /etc/opendkim/key.table
	m4 -D__MAIN_DOMAIN__=$mailserver_domain $HOMEDIR/template/opendkim/trusted_hosts   	/etc/opendkim/trusted.hosts
	cp $HOMEDIR/template/opendkim/opendkim.conf 		/etc/opendkim.conf
        mkdir -p /etc/opendkim/keys/$mailserver_domain
	cd /etc/opendkim/$mailserver_domain &&\
		 opendkim-genkey -s mail -d $mailserver_domain &&\
	 	 chown opendkim:opendkim mail.private
	echo SOCKET=\"inet:12345@localhost\" > /etc/default/opendkim
	
	/etc/init.d/dovecot restart
	/etc/init.d/postfix restart
}

initPackager

mailserver_install $MAILSERVER_NAME $DOMAIN_NAME
